{
  lib,
  stdenv,
  fetchFromGitHub,
  fetchpatch,
  rustPlatform,
  installShellFiles,
  cmake,
  git,
  nixosTests,
  Security,
  Foundation,
  Cocoa,
}:

rustPlatform.buildRustPackage rec {
  pname = "starship";
  version = "1.19.0";

  src = fetchFromGitHub {
    owner = "starship";
    repo = "starship";
    rev = "v${version}";
    hash = "sha256-3IO9hHuhzJsCHU/6BA5ylEKQI2ik6ZiRul/iO/vzii4=";
  };

  patches = [
    (fetchpatch {
      name = "CVE-2024-41815.patch";
      url = "https://github.com/starship/starship/commit/cfc58161e0ec595db90af686ad77a73df6d44d74.patch";
      hash = "sha256-JlhrcCsvIMH1XnFsx2b65Kbbe9Hsy7ffUMha1BISwtI=";
    })
  ];

  nativeBuildInputs = [
    installShellFiles
    cmake
  ];

  buildInputs = lib.optionals stdenv.isDarwin [
    Security
    Foundation
    Cocoa
  ];

  NIX_LDFLAGS = lib.optionals (stdenv.isDarwin && stdenv.isx86_64) [
    "-framework"
    "AppKit"
  ];

  # tries to access HOME only in aarch64-darwin environment when building mac-notification-sys
  preBuild = lib.optionalString (stdenv.isDarwin && stdenv.isAarch64) ''
    export HOME=$TMPDIR
  '';

  postInstall = ''
    installShellCompletion --cmd starship \
      --bash <($out/bin/starship completions bash) \
      --fish <($out/bin/starship completions fish) \
      --zsh <($out/bin/starship completions zsh)

    presetdir=$out/share/starship/presets/
    mkdir -p $presetdir
    cp docs/public/presets/toml/*.toml $presetdir
  '';

  cargoHash = "sha256-zX04gX40dFYsK+R6gafHNtDevzrWiGufMwrGfhqYVG0=";

  nativeCheckInputs = [ git ];

  preCheck = ''
    HOME=$TMPDIR
  '';

  passthru.tests = {
    inherit (nixosTests) starship;
  };

  meta = with lib; {
    description = "A minimal, blazing fast, and extremely customizable prompt for any shell";
    homepage = "https://starship.rs";
    license = licenses.isc;
    maintainers = with maintainers; [
      danth
      davidtwco
      Br1ght0ne
      Frostman
    ];
    mainProgram = "starship";
  };
}
